//----------
// AntiShockHo WebAdmin Interface
//
// Programmed by PurplePants@purplemetalflake.co.uk
//
// Copyright  PurplePants, 2003
//
// WebApplication class (ASH400_LITE_NONMMC.AntiShockHoWeb)
//----------

class AntiShockHoWeb extends WebApplication;

// Config actor...
var AntiShockHo		ASHconf;

var localized string	url_root;

// Store to hold which keybind page is showing
var int		KeyBindPage;


// First things first...
event Init()
{
	local AntiShockHo	ashc;

	Super.Init();

	// Start with nowt, see if it gets set
	ASHconf = none;

	// Find our root class so we can then find the config class...
	foreach Level.AllActors(class'AntiShockHo', ashc)
		{
		if (String(ashc.Class) == "ASH400_LITE_NONMMC.AntiShockHo")
			ASHconf = ashc;
		}

	// Complain if something went wrong
	if (ASHconf == none)
		Log("ASHWeb: *** Config class not found ***");
}

// Is this user the admin
function bool AuthenticateAdmin(WebRequest Request, WebResponse Response)
{
	local string sAdminUser, sAdminPass;

	// Check authentication
	sAdminUser = class'UTServerAdmin'.default.AdminUserName;
	sAdminPass = class'UTServerAdmin'.default.AdminPassword;

	if ((sAdminUser ~= "" || (Caps(Request.UserName) != Caps(sAdminUser)))
		|| (sAdminPass ~= "" || (Caps(Request.Password) != Caps(sAdminPass))))
		{
		return False;
		}
	return True;
}


// All web page requests start here
event Query(WebRequest Request, WebResponse Response)
{
	// If we can't find our options there's no point in doing owt
	if (ASHconf == none)
		{
		Response.SendText("<html><body><B>ERROR : AntiShockHo Config Class not found!</B></html></body>");
		return;
		}

	// User is allowed to access this stuff?
	if (AuthenticateAdmin(Request, Response))
		{
		// Admin, so do the normal WebAdmin stuff
		response.Subst("BugAddress", "ASH-bugs@oldephartes.co.uk");

		// Deal with the particular page requested
		switch (Mid(Request.URI, 1))
			{
			case "":
			case "root":
				QueryRoot(Request, Response);		break;
			case "menu":
				QueryMenu(Request, Response);		break;
			case "main":
				QueryMain(Request, Response);		break;
			case "main_menu":
				QueryMainMenu(Request, Response);	break;
			case "options":
				QueryOptions(Request, Response);	break;
			case "keybind":
				QueryKeybinds(Request, Response);	break;
			case "keybindlist":
				QueryKeybindList(Request, Response);break;
			case "actors":
				QueryActors(Request, Response);		break;
			case "admins":
				QueryAdmins(Request, Response);		break;
			default:
				Response.SendText("<html><body><B>ERROR: Page not found or enabled.</B></html></body>");
			}
		}
	else
		{
		// Neither admin nor automaton, so refuse the connection
		Response.FailAuthentication(class'UTServerAdmin'.default.AdminRealm);
		}

}


// The root document
function QueryRoot(WebRequest Request, WebResponse Response)
{
	Response.Subst("MenuURI", "menu");
	Response.Subst("MainURI", "main");

	Response.IncludeUHTM(url_root$"/root.uhtm");
}

// The upper menu
function QueryMenu(WebRequest Request, WebResponse Response)
{
	Response.Subst("AdminURI", 	"/ServerAdmin");
	Response.Subst("AntiShockHoURI", 	"root");

	Response.IncludeUHTM(url_root$"/menu.uhtm");
	Response.ClearSubst();
}

// The left menu and frameset content
function QueryMain(WebRequest Request, WebResponse Response)
{
	local string	page;

	// Use the default if no page is specified
	page = Request.GetVariable("Page", "options");
	Response.Subst("IndexURI", "main_menu");
	Response.Subst("MainURI", Page);

	Response.IncludeUHTM(url_root$"/main.uhtm");
	Response.ClearSubst();
}

// The left menu
function QueryMainMenu(WebRequest Request, WebResponse Response)
{
	local string	page;

	// Reset to first keybind page
	KeybindPage = 0;

	// Default to the options page
	page = Request.GetVariable("Page", "options");

	Response.Subst("OptionsURI", "main?Page=options");
	Response.Subst("KeybindURI", "main?Page=keybind");
	Response.Subst("KeybindListURI", "main?Page=keybindlist");
	Response.Subst("ActorURI", "main?Page=actors");
	Response.Subst("AdminURI", "main?Page=admins");

	Response.IncludeUHTM(url_root$"/main_menu.uhtm");
	Response.ClearSubst();
}

// The application options page
function QueryOptions(WebRequest Request, WebResponse Response)
{

	// An update...
	if (Request.GetVariable("Apply", "") != "")
		{
		ASHconf.bScanKeybinds = bool(Request.GetVariable("ScanKeybinds", "false"));
		ASHconf.bAnnounceAimbotKeybinds = bool(Request.GetVariable("AnnounceKeybinds", "false"));
		ASHconf.bLogKeyBinds = bool(Request.GetVariable("LogKeyBinds", "false"));
		ASHconf.bChangeAimbotKeybinds = bool(Request.GetVariable("ChangeAimbotKeybinds", "false"));
		ASHconf.bPenalizeAimbotKeybinds = bool(Request.GetVariable("Penalize", "false"));
		ASHconf.bLogAimbotKeybinds = bool(Request.GetVariable("LogAimbotKeybinds", "false"));
		ASHconf.bKickBadActors = bool(Request.GetVariable("KickBadActors", "false"));
		ASHconf.bLogActors = bool(Request.GetVariable("LogActors", "false"));
		ASHconf.szReplacementABKeybind = Request.GetVariable("ReplacementKeybind", "");
		ASHconf.SaveConfig();
		}

	// Set display to match the current options
	if (ASHconf.bScanKeybinds)
		Response.Subst("ScanKeybinds", " checked");
	if (ASHconf.bAnnounceAimbotKeybinds)
		Response.Subst("AnnounceKeybinds", " checked");
	if (ASHconf.bLogKeyBinds)
		Response.Subst("LogKeyBinds", " checked");
	if (ASHconf.bChangeAimbotKeybinds)
		Response.Subst("ChangeAimbotKeybinds", " checked");
	if (ASHconf.bPenalizeAimbotKeybinds)
		Response.Subst("Penalize", " checked");
	if (ASHconf.bLogAimbotKeybinds)
		Response.Subst("LogAimbotKeybinds", " checked");
	if (ASHconf.bKickBadActors)
		Response.Subst("KickBadActors", " checked");
	if (ASHconf.bLogActors)
		Response.Subst("LogActors", " checked");
	Response.Subst("ReplacementKeybind", ASHconf.szReplacementABKeybind);

	Response.Subst("PostAction", "options");
	Response.IncludeUHTM(url_root$"/options.uhtm");
}

// The IPPolicies-alike keybinds list
function QueryKeybinds(WebRequest Request, WebResponse Response)
{
	local int	i, j, RangeBase;
	local int	BindsCount, MaxBinds;

	MaxBinds = ArrayCount(ASHconf.CheatKeybind);

	// A range button is pressed - set the appropriate range
	if (Request.GetVariable("B1", "") != "")
		KeybindPage = 0;
	else if (Request.GetVariable("B51", "") != "")
		KeybindPage = 1;
	else if (Request.GetVariable("B101", "") != "")
		KeybindPage = 2;
	else if (Request.GetVariable("B151", "") != "")
		KeybindPage = 3;
	else if (Request.GetVariable("B201", "") != "")
		KeybindPage = 4;
	else if (Request.GetVariable("B251", "") != "")
		KeybindPage = 5;
	else if (Request.GetVariable("B301", "") != "")
		KeybindPage = 6;
	else if (Request.GetVariable("B351", "") != "")
		KeybindPage = 7;

	// A keybind is changed
	if (Request.GetVariable("Update") != "")
		{
		i = int(Request.GetVariable("KeybindNo", "-1"));
		if (i == -1)
			for (i = 0; i < MaxBinds && ASHconf.CheatKeybind[i] != ""; i++);
		if (i < MaxBinds)
			ASHconf.CheatKeybind[i] = Request.GetVariable("KeyBind");
		ASHconf.SaveConfig();
		}

	// A keybind is deleted
	if (Request.GetVariable("Delete") != "")
		{
		i = int(Request.GetVariable("KeybindNo", "-1"));

		if (i > 0)
			{
			for (i = i; i < MaxBinds-1 && ASHconf.CheatKeybind[i] != ""; i++)
				ASHconf.CheatKeybind[i] = ASHconf.CheatKeybind[i + 1];

			if (i == MaxBinds-1)
				ASHconf.CheatKeybind[i] = "";
			ASHconf.SaveConfig();
			}
		}

	// Change the range select buttons so
	// only ranges with keybinds in can be selected
	for (i = 0; i < MaxBinds; i += 50)
		{
		if (ASHconf.CheatKeybind[i] != "")
			Response.Subst("B"$i$"type", "submit");
		else
			{
			if (KeybindPage > i / 50)	// make sure page is within range
				KeybindPage = i / 50;
			Response.Subst("B"$i$"type", "hidden");
			}
		}

	// Show the keybinds for the page range
	RangeBase = KeybindPage * 50;
	Response.Subst("Range", RangeBase + 1 $ " - " $ RangeBase + 50);
	Response.IncludeUHTM(url_root$"/keybinds-h.uhtm");
	for (i = RangeBase; i < RangeBase + 50 && ASHconf.CheatKeybind[i] != ""; i++)
		{
		Response.Subst("Keybind", ASHconf.CheatKeybind[i]);
		Response.Subst("PostAction", "keybind?KeybindNo="$string(i));
		Response.IncludeUHTM(url_root$"/keybinds-d.uhtm");
		}
	Response.Subst("PostAction", "keybind");
	// Only put a 'new' button on the last page
	if ((KeybindPage + 1 >= MaxBinds / 50) || (ASHconf.CheatKeybind[(KeybindPage + 1) * 50] == ""))
		Response.IncludeUHTM(url_root$"/keybinds-s.uhtm");
	Response.IncludeUHTM(url_root$"/keybinds-f.uhtm");
}


// The keybind big list for mass editing
function QueryKeybindList(WebRequest Request, WebResponse Response)
{
	local int 		i, j, k, MaxBinds, ItemCnt, DropCount;
	local string	BigListData;

	MaxBinds = ArrayCount(ASHconf.CheatKeybind);

	if (Request.GetVariable("Apply", "") != "")
		{
		// Make sure the browser does scripting
		if (Request.GetVariable("Check", "") != "")
			{
			Response.Subst("SmallTitle", "Keybind Big List Problem");
			Response.Subst("Title", "No browser scripting available");
			Response.Subst("Message", "You were told, but would you listen? Hahaha...bonk");
			Response.IncludeUHTM(url_root$"/message.uhtm");
			return;
			}

		ItemCnt = Request.GetVariableCount("KeybindData");

		j = 0;	// Start at keybind 0
		DropCount = ItemCnt;
		for (i = 0; i < ItemCnt; i++)
			{
			if (j >= MaxBinds)	// don't overrun keybind store
				break;

			// Get next keybind to store
			ASHconf.CheatKeybind[i] = Request.GetVariableNumber("KeybindData", ItemCnt - 1 - i);
			DropCount--;
			j++;
			}

		ItemCnt = j;	// Fix real count (excluding dropped items)

		// Clear the rest of the keybinds (if any)
		while (j < MaxBinds)
			{
			ASHconf.CheatKeybind[j] = "";
			j++;
			}
		ASHconf.SaveConfig();


		Response.Subst("Title", "Keybind Big List");
		if (DropCount > 0)
			{
			Response.Subst("SmallTitle", "Keybinds");
			Response.Subst("Message", "Last "$DropCount$" items dropped - only "$MaxBinds$" allowed.");
			Log("ASHWeb: Keybind big list updated with "$ItemCnt$" items ("$DropCount$" dropped).");
			}
		else
			{
			Response.Subst("SmallTitle", "Keybinds");
			Response.Subst("Message", ItemCnt $" keybinds stored, space for " $MaxBinds - ItemCnt$" left.");
			Log("ASHWeb: Keybind big list updated with "$ItemCnt$" items.");
			}
		Response.IncludeUHTM(url_root$"/message.uhtm");
		return;
		}

	for (i = 0; i < MaxBinds && ASHconf.CheatKeybind[i] != ""; i++)
		BigListData = BigListData$Chr(13)$ASHconf.CheatKeybind[i];


	Response.Subst("SmallTitle", "Keybinds");
	Response.Subst("Title", "Keybind Big List");
	Response.Subst("BigListData", BigListData);
	Response.Subst("PostAction", "keybindlist");
	Response.IncludeUHTM(url_root$"/editlist.uhtm");
}

// The IPPolicies-alike actors list
function QueryActors(WebRequest Request, WebResponse Response)
{
	local int	i;
	local int	MaxActors;

	MaxActors = ArrayCount(ASHconf.BadActor);

	// An actor is changed
	if (Request.GetVariable("Update") != "")
		{
		i = int(Request.GetVariable("ItemNo", "-1"));
		if (i == -1)
			for (i = 0; i < MaxActors && ASHconf.BadActor[i] != ""; i++);
		if (i < MaxActors)
			ASHconf.BadActor[i] = Request.GetVariable("Item");
		ASHconf.SaveConfig();
		}

	// An actor is deleted
	if (Request.GetVariable("Delete") != "")
		{
		i = int(Request.GetVariable("ItemNo", "-1"));

		if (i > 0)
			{
			for (i = i; i < MaxActors-1 && ASHconf.BadActor[i] != ""; i++)
				ASHconf.BadActor[i] = ASHconf.BadActor[i + 1];

			if (i == MaxActors-1)
				ASHconf.BadActor[i] = "";
			ASHconf.SaveConfig();
			}
		}

	Response.Subst("SmallTitle", "Actors");
	Response.Subst("Title", "Actor List");
	Response.Subst("TableTitle", "Actors");
	Response.IncludeUHTM(url_root$"/list-h.uhtm");
	for (i = 0; i < MaxActors && ASHconf.BadActor[i] != ""; i++)
		{
		Response.Subst("Item", ASHconf.BadActor[i]);
		Response.Subst("PostAction", "actors?ItemNo="$string(i));
		Response.IncludeUHTM(url_root$"/list-d.uhtm");
		}
	Response.Subst("PostAction", "actors");

	// Don't prompt for a new actor if the list is full
	if (ASHconf.BadActor[MaxActors - 1] == "")
		Response.IncludeUHTM(url_root$"/list-s.uhtm");
	Response.IncludeUHTM(url_root$"/list-f.uhtm");
}

// The IPPolicies-alike admins list
function QueryAdmins(WebRequest Request, WebResponse Response)
{
	local int	i;
	local int	MaxAdmins;

	MaxAdmins = ArrayCount(ASHconf.AdminIP);

	// An actor is changed
	if (Request.GetVariable("Update") != "")
		{
		i = int(Request.GetVariable("ItemNo", "-1"));
		if (i == -1)
			for (i = 0; i < MaxAdmins && ASHconf.AdminIP[i] != ""; i++);
		if (i < MaxAdmins)
			ASHconf.AdminIP[i] = Request.GetVariable("Item");
		ASHconf.SaveConfig();
		}

	// An actor is deleted
	if (Request.GetVariable("Delete") != "")
		{
		i = int(Request.GetVariable("ItemNo", "-1"));

		if (i > 0)
			{
			for (i = i; i < MaxAdmins-1 && ASHconf.AdminIP[i] != ""; i++)
				ASHconf.AdminIP[i] = ASHconf.AdminIP[i + 1];

			if (i == MaxAdmins-1)
				ASHconf.AdminIP[i] = "";
			ASHconf.SaveConfig();
			}
		}

	Response.Subst("SmallTitle", "Admins");
	Response.Subst("Title", "Admin IP List");
	Response.Subst("TableTitle", "Address");
	Response.IncludeUHTM(url_root$"/list-h.uhtm");
	for (i = 0; i < MaxAdmins && ASHconf.AdminIP[i] != ""; i++)
		{
		Response.Subst("Item", ASHconf.AdminIP[i]);
		Response.Subst("PostAction", "admins?ItemNo="$string(i));
		Response.IncludeUHTM(url_root$"/list-d.uhtm");
		}
	Response.Subst("PostAction", "admins");

	if (ASHconf.AdminIP[MaxAdmins - 1] == "")
		Response.IncludeUHTM(url_root$"/list-s.uhtm");
	Response.IncludeUHTM(url_root$"/list-f.uhtm");
}

defaultproperties
{
url_root="ASH"
}
